@@ -4,8 +4,8 @@ use Mojo::Base -base;
 use Imager::Font;
 use Alien::Font::Vera;
 
-our $DATE = '2023-02-02'; # DATE
-our $VERSION = '0.006';
+our $DATE = '2023-02-14'; # DATE
+our $VERSION = '0.007';
 
 has primaryText     => 'black';
 has secondaryText	=> '#363636';
@@ -19,6 +19,11 @@ has itemFill        => '2ab1aa';
 has background      => 'white';
 has font            => sub { Imager::Font->new(file => Alien::Font::Vera::path) };
 has doSwimLanes     => 1;
+has spanInfoWidth   => 205;
+has titleSize       => 200;
+has descriptionSize => 145;
+has resourceStartX  => 145 + 2;
+has resourceSize    => 55;
 
 #26ccbb green
 #43acf2 blue
