@@ -6,8 +6,8 @@ use Project2::Gantt::TextUtils;
 
 use Mojo::Log;
 
-our $DATE = '2023-02-02'; # DATE
-our $VERSION = '0.006';
+our $DATE = '2023-02-14'; # DATE
+our $VERSION = '0.007';
 
 has canvas => undef;
 has task   => undef;
@@ -15,8 +15,6 @@ has skin   => undef;
 
 has log    => sub { Mojo::Log->new };
 
-use constant DESCRIPTION_SIZE => 145;
-
 sub write($self,$height) {
 	$self->_writeInfo($height);
 }
@@ -35,23 +33,23 @@ sub _writeInfo($self, $height) {
 		color  => $bgcolor,
 		xmin   => 0,
 		ymin   => $height,
-		xmax   => DESCRIPTION_SIZE,
+		xmax   => $self->skin->descriptionSize,
 		ymax   => $height + 17,
 		filled => 1,
 	);
 
 	$canvas->box(
 		color  => $bgcolor,
-		xmin   => DESCRIPTION_SIZE,
+		xmin   => $self->skin->descriptionSize,
 		ymin   => $height,
-		xmax   => 200,
+		xmax   => $self->skin->titleSize,
 		ymax   => $height + 17,
 		filled => 1,
 	);
 
-	$log->debug(truncate($task->description,DESCRIPTION_SIZE));
+	$log->debug(truncate($task->description,$self->skin->descriptionSize));
 
-	my $description = truncate($task->description, DESCRIPTION_SIZE);
+	my $description = truncate($task->description, $self->skin->descriptionSize);
 	$log->debug("_writeInfo description=$description");
 	$canvas->string(
 		x      => 2,
@@ -65,10 +63,10 @@ sub _writeInfo($self, $height) {
 
 	# if this is a task, write name... sub-projects aren't associated with a specific resource
 	if($task->isa("Project2::Gantt::Task")){
-		my $name = truncate($task->resources->[0]->name,55);
+		my $name = truncate($task->resources->[0]->name,$self->skin->resourceSize);
 		$log->debug("_writeInfo name=$name");
 		$canvas->string(
-			x      => 147,
+			x      => $self->skin->resourceStartX,
 			y      => $height + 12,
 			string => $name,
 			font   => $self->skin->font,
